rayvision_max Changelog
=========================
Here you can see the full list of changes between each tagged release.

Version 1.0.0 (June 28th, 2020)
------------------------------------
  - SDK starts to support max software
